@@ -14,7 +14,12 @@ import aws_cdk.core._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-lambda-s3", "1.46.0", __name__[0:-6], "aws-lambda-s3@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-lambda-s3",
+    "1.51.0",
+    __name__[0:-6],
+    "aws-lambda-s3@1.51.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
